@@ -140,7 +140,10 @@ def request(scope, *, requires_user=False, category):
             if requires_user and self.grant is Grant.CLIENT_CREDENTIALS:
                 raise AccessDeniedError("To access this endpoint you must be "
                     "authorized using the authorization code grant. You are "
-                    "currently authorized with the client credentials grant")
+                    "currently authorized with the client credentials grant."
+                    "\n\n"
+                    "For more details, see "
+                    "https://circleguard.github.io/ossapi/grants.html.")
 
             # we may need to edit this later so convert from tuple
             args = list(args)
@@ -284,6 +287,15 @@ class Ossapi:
         taking responsibility for making sure it is unique / unused, and also
         for remembering the key you passed if you wish to eg remove the token in
         the future, which requires the key.
+    access_token: str
+        Access token from the osu! api. Allows instantiating
+        :class:`~ossapi.ossapiv2.Ossapi` after manually authenticating with the
+        osu! api.
+    refresh_token: str
+        Refresh token from the osu! api. Allows instantiating
+        :class:`~ossapi.ossapiv2.Ossapi` after manually authenticating with the
+        osu! api. Optional if using :data:`Grant.CLIENT_CREDENTIALS
+        <ossapi.ossapiv2.Grant.CLIENT_CREDENTIALS>`.
     """
     TOKEN_URL = "https://osu.ppy.sh/oauth/token"
     AUTH_CODE_URL = "https://osu.ppy.sh/oauth/authorize"
@@ -1733,7 +1745,7 @@ class Ossapi:
         query
             Search query.
         mode
-            Filter results by type (forum, wiki, player, etc.).
+            Filter results by type (wiki or player).
         page
             Pagination for results.
 
@@ -1786,7 +1798,7 @@ class Ossapi:
     @request(Scope.IDENTIFY, category="me")
     def get_me(self,
         mode: Optional[GameModeT] = None
-    ):
+    ) -> User:
         """
         Get data about the authenticated user.
 
@@ -1895,7 +1907,7 @@ class Ossapi:
         variant: Optional[str] = None
     ) -> Rankings:
         """
-        Get current rankings for the specified game mode. Can specify ``type_``
+        Get current rankings for the specified game mode. Can specify ``type``
         to get different types of rankings (performance, score, country, etc).
 
         Parameters
