@@ -59,11 +59,6 @@ from ossapi.replay import Replay
 
 
 class Oauth2SessionAsync(OAuth2Session):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        from aiohttp import ClientSession
-        self.session = ClientSession()
-
     # this method is shamelessly copied from `OAuth2Session.request`, modified
     # to call `self.session.request` instead of `super().request`.
     # Any OAuth2Session code which calls `request` will remain sync, but we have
@@ -111,9 +106,14 @@ class Oauth2SessionAsync(OAuth2Session):
                 else:
                     raise
 
-        return await self.session.request(
-            method, url, headers=headers, data=data, **kwargs
-        )
+        # No, we should not be using a session for every request. Yes, we are
+        # not achieving 100% performance by doing this. The benefit is that we
+        # don't require `async with OssapiAsync(...) as api:` syntax in order to
+        # use ossapi.
+        async with aiohttp.ClientSession() as session:
+            return await session.request(
+                method, url, headers=headers, data=data, **kwargs
+            )
 
 # our `request` function below relies on the ordering of these types. The
 # base type must come first, with any auxiliary types that the base type accepts
@@ -209,7 +209,10 @@ def request(scope, *, requires_user=False, category):
             if requires_user and self.grant is Grant.CLIENT_CREDENTIALS:
                 raise AccessDeniedError("To access this endpoint you must be "
                     "authorized using the authorization code grant. You are "
-                    "currently authorized with the client credentials grant")
+                    "currently authorized with the client credentials grant."
+                    "\n\n"
+                    "For more details, see "
+                    "https://circleguard.github.io/ossapi/grants.html.")
 
             # we may need to edit this later so convert from tuple
             args = list(args)
@@ -354,6 +357,15 @@ class OssapiAsync:
         taking responsibility for making sure it is unique / unused, and also
         for remembering the key you passed if you wish to eg remove the token in
         the future, which requires the key.
+    access_token: str
+        Access token from the osu! api. Allows instantiating
+        :class:`~ossapi.ossapiv2.Ossapi` after manually authenticating with the
+        osu! api.
+    refresh_token: str
+        Refresh token from the osu! api. Allows instantiating
+        :class:`~ossapi.ossapiv2.Ossapi` after manually authenticating with the
+        osu! api. Optional if using :data:`Grant.CLIENT_CREDENTIALS
+        <ossapi.ossapiv2.Grant.CLIENT_CREDENTIALS>`.
     """
     TOKEN_URL = "https://osu.ppy.sh/oauth/token"
     AUTH_CODE_URL = "https://osu.ppy.sh/oauth/authorize"
@@ -1806,7 +1818,7 @@ class OssapiAsync:
         query
             Search query.
         mode
-            Filter results by type (forum, wiki, player, etc.).
+            Filter results by type (wiki or player).
         page
             Pagination for results.
 
@@ -1968,7 +1980,7 @@ class OssapiAsync:
         variant: Optional[str] = None
     ) -> Rankings:
         """
-        Get current rankings for the specified game mode. Can specify ``type_``
+        Get current rankings for the specified game mode. Can specify ``type``
         to get different types of rankings (performance, score, country, etc).
 
         Parameters
